window.Gleam.initSearch([{"doc":"parz","title":"parz","content":"# parz\n\nA simple parser combinator library\n\n&gt; Trying to learn [Gleam]() while also Learning about Parser Combinators using\n&gt; [The YouTube Series by Low Byte Productions](https://www.youtube.com/playlist?list=PLP29wDx6QmW5yfO1LAgO8kU3aQEj8SIrU)\n&gt; and [Understanding Parser Combinators](https://fsharpforfunandprofit.com/posts/understanding-parser-combinators/)\n\n[![Package Version](https://img.shields.io/hexpm/v/parz)](https://hex.pm/packages/parz)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/parz/)\n\nThe project exposes the following modules:\n\n1. `parz.` - contains the `run` method which is used for executing a parser\n2. `parz/combinators` - the parser combinator library\n3. `pars/parsers` - some simple, prmiitive parsers\n\n## Usage\n\n```sh\ngleam add parz\n```\n\n```gleam\nimport parz.{run}\nimport pars/combinators\nimport pars/parsers\n\npub fn main() {\n  // For an example usage look at the `tests/sample_parser_test.gleam` file\n  let parser = // .. define a parser\n\n  let result = run(parser, content_to_parse)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/parz&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"parz","title":"run","content":"pub fn run(parser: fn(a) -&gt; b, input: a) -&gt; b\n\nSynonyms:\nparz.run\nparz run","url":"parz.html#run"},{"doc":"parz","title":"parz","content":"","url":"parz.html"},{"doc":"parz/types","title":"Err","content":"pub type Err =\n  String\n\n\nSynonyms:\nparz/types.Err\nparz/types Err","url":"parz/types.html#Err"},{"doc":"parz/types","title":"Parser","content":"pub type Parser(a) =\n  fn(String) -&gt; Result(ParserState(a), Err)\n\n\nSynonyms:\nparz/types.Parser\nparz/types Parser","url":"parz/types.html#Parser"},{"doc":"parz/types","title":"ParserState","content":"pub type ParserState(a) {\n  ParserState(matched: a, remaining: String)\n}\n\nParserState(matched: a, remaining: String)\n\n\nSynonyms:\nparz/types.ParserState\nparz/types ParserState","url":"parz/types.html#ParserState"},{"doc":"parz/types","title":"parz/types","content":"","url":"parz/types.html"},{"doc":"parz/combinators","title":"as_list","content":"pub fn as_list(\n  parser: fn(String) -&gt; Result(ParserState(a), String),\n) -&gt; fn(String) -&gt; Result(ParserState(List(a)), String)\n\nSynonyms:\nparz/combinators.as_list\nparz/combinators as_list","url":"parz/combinators.html#as_list"},{"doc":"parz/combinators","title":"between","content":"pub fn between(\n  l: fn(String) -&gt; Result(ParserState(a), String),\n  keep: fn(String) -&gt; Result(ParserState(b), String),\n  r: fn(String) -&gt; Result(ParserState(c), String),\n) -&gt; fn(String) -&gt; Result(ParserState(b), String)\n\nSynonyms:\nparz/combinators.between\nparz/combinators between","url":"parz/combinators.html#between"},{"doc":"parz/combinators","title":"choice","content":"pub fn choice(\n  parsers: List(fn(String) -&gt; Result(ParserState(a), String)),\n) -&gt; fn(String) -&gt; Result(ParserState(a), String)\n\nSynonyms:\nparz/combinators.choice\nparz/combinators choice","url":"parz/combinators.html#choice"},{"doc":"parz/combinators","title":"concat_str","content":"pub fn concat_str(\n  parser: fn(String) -&gt; Result(ParserState(List(String)), String),\n) -&gt; fn(String) -&gt; Result(ParserState(String), String)\n\nSynonyms:\nparz/combinators.concat_str\nparz/combinators concat_str","url":"parz/combinators.html#concat_str"},{"doc":"parz/combinators","title":"label_error","content":"pub fn label_error(\n  parser: fn(a) -&gt; Result(b, c),\n  message: d,\n) -&gt; fn(a) -&gt; Result(b, d)\n\nSynonyms:\nparz/combinators.label_error\nparz/combinators label_error","url":"parz/combinators.html#label_error"},{"doc":"parz/combinators","title":"left","content":"pub fn left(\n  l: fn(String) -&gt; Result(ParserState(a), String),\n  r: fn(String) -&gt; Result(ParserState(b), String),\n) -&gt; fn(String) -&gt; Result(ParserState(a), String)\n\nSynonyms:\nparz/combinators.left\nparz/combinators left","url":"parz/combinators.html#left"},{"doc":"parz/combinators","title":"many","content":"pub fn many(\n  parser: fn(String) -&gt; Result(ParserState(a), String),\n) -&gt; fn(String) -&gt; Result(ParserState(List(a)), b)\n\nSynonyms:\nparz/combinators.many\nparz/combinators many","url":"parz/combinators.html#many"},{"doc":"parz/combinators","title":"many1","content":"pub fn many1(\n  parser: fn(String) -&gt; Result(ParserState(a), String),\n) -&gt; fn(String) -&gt; Result(ParserState(List(a)), String)\n\nSynonyms:\nparz/combinators.many1\nparz/combinators many1","url":"parz/combinators.html#many1"},{"doc":"parz/combinators","title":"map","content":"pub fn map(\n  parser: fn(String) -&gt; Result(ParserState(a), String),\n  transform: fn(a) -&gt; b,\n) -&gt; fn(String) -&gt; Result(ParserState(b), String)\n\nSynonyms:\nparz/combinators.map\nparz/combinators map","url":"parz/combinators.html#map"},{"doc":"parz/combinators","title":"right","content":"pub fn right(\n  l: fn(String) -&gt; Result(ParserState(a), String),\n  r: fn(String) -&gt; Result(ParserState(b), String),\n) -&gt; fn(String) -&gt; Result(ParserState(b), String)\n\nSynonyms:\nparz/combinators.right\nparz/combinators right","url":"parz/combinators.html#right"},{"doc":"parz/combinators","title":"separator","content":"pub fn separator(\n  parser: fn(String) -&gt; Result(ParserState(a), String),\n  sep: fn(String) -&gt; Result(ParserState(b), String),\n) -&gt; fn(String) -&gt; Result(ParserState(List(a)), c)\n\nSynonyms:\nparz/combinators.separator\nparz/combinators separator","url":"parz/combinators.html#separator"},{"doc":"parz/combinators","title":"separator1","content":"pub fn separator1(\n  parser: fn(String) -&gt; Result(ParserState(a), String),\n  sep: fn(String) -&gt; Result(ParserState(b), String),\n) -&gt; fn(String) -&gt; Result(ParserState(List(a)), String)\n\nSynonyms:\nparz/combinators.separator1\nparz/combinators separator1","url":"parz/combinators.html#separator1"},{"doc":"parz/combinators","title":"sequence","content":"pub fn sequence(\n  parsers: List(fn(String) -&gt; Result(ParserState(a), String)),\n) -&gt; fn(String) -&gt; Result(ParserState(List(a)), String)\n\nSynonyms:\nparz/combinators.sequence\nparz/combinators sequence","url":"parz/combinators.html#sequence"},{"doc":"parz/combinators","title":"try_map","content":"pub fn try_map(\n  parser: fn(String) -&gt; Result(ParserState(a), String),\n  transform: fn(a) -&gt; Result(b, String),\n) -&gt; fn(String) -&gt; Result(ParserState(b), String)\n\nSynonyms:\nparz/combinators.try_map\nparz/combinators try_map","url":"parz/combinators.html#try_map"},{"doc":"parz/combinators","title":"parz/combinators","content":"","url":"parz/combinators.html"},{"doc":"parz/parsers","title":"digits","content":"pub fn digits() -&gt; fn(String) -&gt;\n  Result(ParserState(String), String)\n\nSynonyms:\nparz/parsers.digits\nparz/parsers digits","url":"parz/parsers.html#digits"},{"doc":"parz/parsers","title":"letters","content":"pub fn letters() -&gt; fn(String) -&gt;\n  Result(ParserState(String), String)\n\nSynonyms:\nparz/parsers.letters\nparz/parsers letters","url":"parz/parsers.html#letters"},{"doc":"parz/parsers","title":"regex","content":"pub fn regex(\n  regex: String,\n) -&gt; fn(String) -&gt; Result(ParserState(String), String)\n\nSynonyms:\nparz/parsers.regex\nparz/parsers regex","url":"parz/parsers.html#regex"},{"doc":"parz/parsers","title":"str","content":"pub fn str(\n  start: String,\n) -&gt; fn(String) -&gt; Result(ParserState(String), String)\n\nSynonyms:\nparz/parsers.str\nparz/parsers str","url":"parz/parsers.html#str"},{"doc":"parz/parsers","title":"parz/parsers","content":"","url":"parz/parsers.html"}]);